VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package arcgis

Package {arcgis}


Title: ArcGIS Location Services Meta-Package
Version: 0.2.0
Description: Provides easy installation and loading of core ArcGIS location services packages 'arcgislayers', 'arcgisutils', 'arcgisgeocode', and 'arcgisplaces'. Enabling developers to interact with spatial data and services from 'ArcGIS Online', 'ArcGIS Enterprise', and 'ArcGIS Platform'. Learn more about the 'arcgis' meta-package at https://developers.arcgis.com/r-bridge/.
Language: en
License: Apache License (≥ 2)
Encoding: UTF-8
Imports: arcgisgeocode (≥ 0.1.0), arcgislayers (≥ 0.2.0), arcgisplaces (≥ 0.1.0), arcgisutils (≥ 0.3.0), cli, httr2 (≥ 1.0.0), utils
RoxygenNote: 7.3.2
Suggests: arcpbf, calcite, testthat (≥ 3.0.0)
Config/testthat/edition: 3
Config/Needs/website: rmarkdown
URL: https://github.com/R-ArcGIS/arcgis/, https://developers.arcgis.com/r-bridge/
Config/rextendr/version: 0.3.1.9000
SystemRequirements: Cargo (Rust's package manager), rustc
NeedsCompilation: no
Packaged: 2025-04-23 20:02:10 UTC; josiahparry
Author: Josiah Parry ORCID iD [aut, cre]
Maintainer: Josiah Parry <josiah.parry@gmail.com>
Repository: CRAN
Date/Publication: 2025-04-25 12:10:05 UTC

arcgis: ArcGIS Location Services Meta-Package

Description

Provides easy installation and loading of core ArcGIS location services packages 'arcgislayers', 'arcgisutils', 'arcgisgeocode', and 'arcgisplaces'. Enabling developers to interact with spatial data and services from 'ArcGIS Online', 'ArcGIS Enterprise', and 'ArcGIS Platform'. Learn more about the 'arcgis' meta-package at https://developers.arcgis.com/r-bridge/.

Author(s)

Maintainer: Josiah Parry josiah.parry@gmail.com (ORCID)

See Also

Useful links:


List all arcgis packages

Description

List all arcgis packages

Usage

arcgis_packages(include_self = TRUE)

Arguments

include_self

default TRUE. Includes the "arcgis" package name in the resultant character vector.

Value

A character vector of package names included in the "arcgis" meta-package.

Examples

arcgis_packages()

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.